{{ warning("postcard.html is an old template path, that is no longer used by ablog. Please use ablog/postcard.html instead.") }}
{% if pagename in ablog %}
<div class="ablog-sidebar-item ablog__postcard">
{% set fa = ablog.fontawesome %}
{% set post = ablog[pagename] %}
<h2>
  {% if post.published %}
  {% if fa %}
  <i class="fa fa-calendar"></i>
  {% endif %}
  {{ post.date.strftime(ablog.post_date_format) }}
  {% else %}
  {% if fa %}
  <i class="fa fa-pencil"></i>
  {% endif %}
  {% if post.date %}
  {{ post.date.strftime(ablog.post_date_format)}}
  {% else %}
  Draft
  {% endif %}
  {% endif %}
</h2>
<ul>
  {% include "ablog/postcard2.html" %}
</ul>
</div>
{% endif %}
