{% if ablog.tags %}
<div class="ablog-sidebar-item ablog__tags">
<h3><a href="{{ pathto(ablog.tags.path) }}">{{ gettext('Tags') }}</a></h3>
<ul class="ablog-cloud">
  {% for coll in ablog.tags %}
  {% if coll %}
  <li class="ablog-cloud ablog-cloud-{{ coll.relsize(5, 1) }}">
    <a href="{{ pathto(coll.docname) }}">{{ coll }}</a>
  </li>
  {% endif %}
  {% endfor %}
</ul>
</div>
{% endif %}
