{{ warning("recentposts.html is an old template path, that is no longer used by ablog. Please use ablog/recentposts.html instead.") }}
{% if ablog %}
<div class="ablog-sidebar-item ablog__recentposts">
<h3>
  <a href="{{ pathto(ablog.blog_path) }}">{{ gettext('Recent Posts') }}</a>
</h3>
<ul>
  {% set pcount = 1 %}
  {% for recent in ablog.recent(5, pagename) %}
  <li>
    <a href="{{ pathto(recent.docname) }}{{ anchor(recent) }}">
      {{ recent.date.strftime(ablog.post_date_format_short) + " - " + recent.title }}
    </a>
  </li>
  {% endfor %}
</ul>
</div>
{% endif %}
